import { MatrixClient } from "matrix-js-sdk/src/client";
import { IUploadOpts } from "matrix-js-sdk/src/@types/requests";
import { IAbortablePromise, IImageInfo } from "matrix-js-sdk/src/@types/partials";
import { IEventRelation } from "matrix-js-sdk/src";
import { IEncryptedFile } from "./customisations/models/IMediaEventContent";
import { IUpload } from "./models/IUpload";
export declare const BLURHASH_FIELD = "xyz.amorgan.blurhash";
export declare class UploadCanceledError extends Error {
}
/**
 * Upload the file to the content repository.
 * If the room is encrypted then encrypt the file before uploading.
 *
 * @param {MatrixClient} matrixClient The matrix client to upload the file with.
 * @param {String} roomId The ID of the room being uploaded to.
 * @param {File} file The file to upload.
 * @param {Function?} progressHandler optional callback to be called when a chunk of
 *    data is uploaded.
 * @return {Promise} A promise that resolves with an object.
 *  If the file is unencrypted then the object will have a "url" key.
 *  If the file is encrypted then the object will have a "file" key.
 */
export declare function uploadFile(matrixClient: MatrixClient, roomId: string, file: File | Blob, progressHandler?: IUploadOpts["progressHandler"]): IAbortablePromise<{
    url?: string;
    file?: IEncryptedFile;
}>;
export default class ContentMessages {
    private inprogress;
    private mediaConfig;
    sendStickerContentToRoom(url: string, roomId: string, threadId: string | null, info: IImageInfo, text: string, matrixClient: MatrixClient): Promise<import("matrix-js-sdk/src").ISendEventResponse>;
    getUploadLimit(): number;
    sendContentListToRoom(files: File[], roomId: string, relation: IEventRelation | null, matrixClient: MatrixClient): Promise<void>;
    getCurrentUploads(relation?: IEventRelation): IUpload[];
    cancelUpload(promise: Promise<any>, matrixClient: MatrixClient): void;
    private sendContentToRoom;
    private isFileSizeAcceptable;
    private ensureMediaConfigFetched;
    static sharedInstance(): ContentMessages;
}
