import React from 'react';
import { RoomMember } from "matrix-js-sdk/src/models/room-member";
import { MatrixCall } from 'matrix-js-sdk/src/webrtc/call';
interface IRecentUser {
    userId: string;
    user: RoomMember;
    lastActive: number;
}
export declare const KIND_DM = "dm";
export declare const KIND_INVITE = "invite";
export declare const KIND_CALL_TRANSFER = "call_transfer";
declare enum TabId {
    UserDirectory = "users",
    DialPad = "dialpad"
}
export declare abstract class Member {
    /**
     * The display name of this Member. For users this should be their profile's display
     * name or user ID if none set. For 3PIDs this should be the 3PID address (email).
     */
    abstract get name(): string;
    /**
     * The ID of this Member. For users this should be their user ID. For 3PIDs this should
     * be the 3PID address (email).
     */
    abstract get userId(): string;
    /**
     * Gets the MXC URL of this Member's avatar. For users this should be their profile's
     * avatar MXC URL or null if none set. For 3PIDs this should always be null.
     */
    abstract getMxcAvatarUrl(): string;
}
interface IInviteDialogProps {
    onFinished: (toInvite?: string[]) => void;
    kind: string;
    roomId: string;
    call: MatrixCall;
    initialText: string;
}
interface IInviteDialogState {
    targets: Member[];
    filterText: string;
    recents: {
        user: Member;
        userId: string;
    }[];
    numRecentsShown: number;
    suggestions: {
        user: Member;
        userId: string;
    }[];
    numSuggestionsShown: number;
    serverResultsMixin: {
        user: Member;
        userId: string;
    }[];
    threepidResultsMixin: {
        user: Member;
        userId: string;
    }[];
    canUseIdentityServer: boolean;
    tryingIdentityServer: boolean;
    consultFirst: boolean;
    dialPadValue: string;
    currentTabId: TabId;
    busy: boolean;
    errorText: string;
}
export default class InviteDialog extends React.PureComponent<IInviteDialogProps, IInviteDialogState> {
    static defaultProps: {
        kind: string;
        initialText: string;
    };
    private closeCopiedTooltip;
    private debounceTimer;
    private editorRef;
    private numberEntryFieldRef;
    private unmounted;
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private onConsultFirstChange;
    static buildRecents(excludedTargetIds: Set<string>): IRecentUser[];
    private buildSuggestions;
    private shouldAbortAfterInviteError;
    private convertFilter;
    private startDm;
    private inviteUsers;
    private transferCall;
    private onKeyDown;
    private onCancel;
    private updateSuggestions;
    private updateFilter;
    private showMoreRecents;
    private showMoreSuggestions;
    private toggleMember;
    private removeMember;
    private onPaste;
    private onClickInputArea;
    private onUseDefaultIdentityServerClick;
    private onManageSettingsClick;
    private onCommunityInviteClick;
    private renderSection;
    private renderEditor;
    private renderIdentityServerWarning;
    private onDialFormSubmit;
    private onDialChange;
    private onDigitPress;
    private onDeletePress;
    private onTabChange;
    private onLinkClick;
    private onCopyClick;
    render(): JSX.Element;
}
export {};
