import { ActionPayload } from "../../dispatcher/payloads";
import { ReadyWatchingStore } from '../ReadyWatchingStore';
import { IRightPanelCard } from './RightPanelStoreIPanelState';
/**
 * A class for tracking the state of the right panel between layouts and
 * sessions. This state includes a history for each room. Each history element
 * contains the phase (e.g. RightPanelPhase.RoomMemberInfo) and the state (e.g.
 * the member) associated with it.
 * Groups are treated the same as rooms (they are also stored in the byRoom
 * object). This is possible since the store keeps track of the opened
 * room/group -> the store will provide the correct history for that group/room.
*/
export default class RightPanelStore extends ReadyWatchingStore {
    private static internalInstance;
    private viewedRoomId;
    private isViewingRoom?;
    private dispatcherRefRightPanelStore;
    private isReady;
    private global?;
    private byRoom;
    private constructor();
    protected onReady(): Promise<any>;
    destroy(): void;
    protected onNotReady(): Promise<any>;
    get isOpenForRoom(): boolean;
    get roomPhaseHistory(): Array<IRightPanelCard>;
    get currentCard(): IRightPanelCard;
    currentCardForRoom(roomId: string): IRightPanelCard;
    get previousCard(): IRightPanelCard;
    get isOpenForGroup(): boolean;
    get groupPhaseHistory(): Array<IRightPanelCard>;
    get currentGroup(): IRightPanelCard;
    get previousGroup(): IRightPanelCard;
    setCard(card: IRightPanelCard, allowClose?: boolean, roomId?: string): void;
    setCards(cards: IRightPanelCard[], allowClose?: boolean, roomId?: string): void;
    pushCard(card: IRightPanelCard, allowClose?: boolean, roomId?: string): void;
    popCard(roomId?: string): IRightPanelCard;
    togglePanel(roomId?: string): void;
    private loadCacheFromSettings;
    private emitAndUpdateSettings;
    private filterValidCards;
    private isCardStateValid;
    private setRightPanelCache;
    private getVerificationRedirect;
    private isPhaseActionValid;
    private onVerificationRequestUpdate;
    onRoomViewStoreUpdate: () => void;
    onDispatch(payload: ActionPayload): void;
    static get instance(): RightPanelStore;
}
