import { ListIteratee, Many } from "lodash";
import { Room } from "matrix-js-sdk/src/models/room";
import { IRoomCapability } from "matrix-js-sdk/src/client";
import { AsyncStoreWithClient } from "../AsyncStoreWithClient";
import { ActionPayload } from "../../dispatcher/payloads";
import { SpaceNotificationState } from "../notifications/SpaceNotificationState";
import { ISuggestedRoom, MetaSpace, SpaceKey } from ".";
interface IState {
}
export declare const getChildOrder: (order: string, ts: number, roomId: string) => Array<Many<ListIteratee<any>>>;
export declare class SpaceStoreClass extends AsyncStoreWithClient<IState> {
    private rootSpaces;
    private parentMap;
    private notificationStateMap;
    private spaceFilteredRooms;
    private spaceFilteredUsers;
    private _activeSpace?;
    private _suggestedRooms;
    private _invitedSpaces;
    private spaceOrderLocalEchoMap;
    private _restrictedJoinRuleSupport?;
    private _allRoomsInHome;
    private _enabledMetaSpaces;
    constructor();
    get invitedSpaces(): Room[];
    get enabledMetaSpaces(): MetaSpace[];
    get spacePanelSpaces(): Room[];
    get activeSpace(): SpaceKey;
    get activeSpaceRoom(): Room | null;
    get suggestedRooms(): ISuggestedRoom[];
    get allRoomsInHome(): boolean;
    setActiveRoomInSpace(space: SpaceKey): void;
    get restrictedJoinRuleSupport(): IRoomCapability;
    /**
     * Sets the active space, updates room list filters,
     * optionally switches the user's room back to where they were when they last viewed that space.
     * @param space which space to switch to.
     * @param contextSwitch whether to switch the user's context,
     * should not be done when the space switch is done implicitly due to another event like switching room.
     */
    setActiveSpace(space: SpaceKey, contextSwitch?: boolean): void;
    private loadSuggestedRooms;
    fetchSuggestedRooms: (space: Room, limit?: number) => Promise<ISuggestedRoom[]>;
    addRoomToSpace(space: Room, roomId: string, via: string[], suggested?: boolean, autoJoin?: boolean): Promise<import("matrix-js-sdk/src").ISendEventResponse>;
    getChildren(spaceId: string): Room[];
    getChildRooms(spaceId: string): Room[];
    getChildSpaces(spaceId: string): Room[];
    getParents(roomId: string, canonicalOnly?: boolean): Room[];
    getCanonicalParent(roomId: string): Room | null;
    getKnownParents(roomId: string): Set<string>;
    isRoomInSpace(space: SpaceKey, roomId: string): boolean;
    getSpaceFilteredRoomIds: (space: SpaceKey) => Set<string>;
    getSpaceFilteredUserIds: (space: SpaceKey) => Set<string>;
    private markTreeChildren;
    private findRootSpaces;
    private rebuildSpaceHierarchy;
    private rebuildParentMap;
    private rebuildHomeSpace;
    private rebuildMetaSpaces;
    private updateNotificationStates;
    private showInHomeSpace;
    private static isInSpace;
    private static getSpaceMembers;
    private onMemberUpdate;
    private onMembersUpdate;
    private onRoomsUpdate;
    private switchSpaceIfNeeded;
    private switchToRelatedSpace;
    private onRoom;
    private notifyIfOrderChanged;
    private onRoomState;
    private onRoomStateMembers;
    private onRoomAccountData;
    private onRoomFavouriteChange;
    private onRoomDmChange;
    private onAccountData;
    protected reset(): Promise<void>;
    protected onNotReady(): Promise<void>;
    protected onReady(): Promise<void>;
    private goToFirstSpace;
    protected onAction(payload: ActionPayload): Promise<void>;
    getNotificationState(key: SpaceKey): SpaceNotificationState;
    traverseSpace(spaceId: string, fn: (roomId: string) => void, includeRooms?: boolean, parentPath?: Set<string>): void;
    private getSpaceTagOrdering;
    private sortRootSpaces;
    private setRootSpaceOrder;
    moveRootSpace(fromIndex: number, toIndex: number): void;
}
export default class SpaceStore {
    static spacesEnabled: boolean;
    private static internalInstance;
    static get instance(): SpaceStoreClass;
}
export {};
