export declare enum InviteState {
    Invited = "invited",
    Error = "error"
}
export declare type CompletionStates = Record<string, InviteState>;
/**
 * Invites multiple addresses to a room or group, handling rate limiting from the server
 */
export default class MultiInviter {
    private readonly progressCallback?;
    private readonly roomId?;
    private readonly groupId?;
    private canceled;
    private addresses;
    private busy;
    private _fatal;
    private completionStates;
    private errors;
    private deferred;
    private reason;
    /**
     * @param {string} targetId The ID of the room or group to invite to
     * @param {function} progressCallback optional callback, fired after each invite.
     */
    constructor(targetId: string, progressCallback?: () => void);
    get fatal(): boolean;
    /**
     * Invite users to this room. This may only be called once per
     * instance of the class.
     *
     * @param {array} addresses Array of addresses to invite
     * @param {string} reason Reason for inviting (optional)
     * @returns {Promise} Resolved when all invitations in the queue are complete
     */
    invite(addresses: any, reason?: string): Promise<CompletionStates>;
    /**
     * Stops inviting. Causes promises returned by invite() to be rejected.
     */
    cancel(): void;
    getCompletionState(addr: string): InviteState;
    getErrorText(addr: string): string;
    private inviteToRoom;
    private doInvite;
    private inviteMore;
}
